#!/usr/bin/env python
#coding: utf-8

# germanizer.py - class for German language message parser
# Copyright (C) Bohdan R. Rau 2011 <ethanak@polip.com>
#
# This program is free software; you can redistribute it and/or
# modify it under the terms of the GNU Lesser General Public
# License as published by the Free Software Foundation; either
# version 2.1 of the License, or (at your option) any later version.
#
# This program is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
# Lesser General Public License for more details.
#
# You should have received a copy of the GNU Lesser General Public
# License along with this program.  If not, write to:
# 	The Free Software Foundation, Inc.,
# 	51 Franklin Street, Fifth Floor
# 	Boston, MA  02110-1301, USA.


from spdsimple.phonetizer import Latinizer

class Germanizer(Latinizer):
	"""
	Specific-language (German) example.
	In this case no method of Latinizer or Phonetizer
	was overridden (yet), but class contains
	large data initializers not very interesting
	to speech-dispatcher module writer
	"""
	def __init__(self,charset='iso-8859-1'):
		Latinizer.__init__(self,
			charset=charset,
			speakable='ß',
			charnames={
				' ':'Blank',
				'.':'Punkt',
				'*':'Stern',
				'+':'Plus',
				'=':'gleich',
				'#':'Numer',
				'€':'Euro',
				'£':'Pound',
				'&':'und',
				'@':'Klammeraffe',
				'~':'Tilde',
				'°':'Gerat',
				'_':'Unterstrich',
				'"':'Zitat',
				'/':'Slasch',
				'\\':'Backslasch',
				'$':'Dollar',
				'(':'Klammer auf',
				')':'Klammer zu',
				'[':'eckige klammer auf',
				']':'eckige klammer zu',
				'{':'geschweifte Klammer auf',
				'}':'geschweifte Klammer zu',
				':':'Doppelpunkt',
				';':'Semikolon',
				',':'Komma',
				'!':'Ausrufezeichen',
				'?':'Fragezeichen',
				'-':'Bindestrich',
				'<':'kleiner als',
				'>':'größer als'},
			keynames={
				'underscore':'Unterstrich',
				'space':'Blank',
				' ':'Blank',
				'double-quote':'Zitat'},
			transmap={
				'š':'sch',
				'Š':'Sch',
				'č':'tsch',
				'Č':'Tsch',
				'ś':'sch',
				'Ś':'sch',
				'ć':'tsch',
				'Ć':'tsch',
				'ñ':'nj',
				'Ñ':'Nj',
				'å':'o',
				'Å':'O',
				'æ':'ä',
				'Æ':'ä',
				'ç':'s',
				'Ç':'s',
				'œ':'ö',
				'Œ':'Ö',
				'ø':'ö',
				'Ø':'Ö'
				},
			untrans="äÄüÜöÖß",
			punctuation=",.?!\";:-",
			capformat="groß %s",
			charformat="zeichen %d",
			accents={'diaeresis':u'umlaut',
					'double acute':u'hungarumlaut'}
		)


