#!/usr/bin/env python
#coding: utf-8

# germanizer.py - class for Swedish language message parser
# Copyright (C) Bohdan R. Rau 2013 <ethanak@polip.com>
#
# This program is free software; you can redistribute it and/or
# modify it under the terms of the GNU Lesser General Public
# License as published by the Free Software Foundation; either
# version 2.1 of the License, or (at your option) any later version.
#
# This program is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
# Lesser General Public License for more details.
#
# You should have received a copy of the GNU Lesser General Public
# License along with this program.  If not, write to:
# 	The Free Software Foundation, Inc.,
# 	51 Franklin Street, Fifth Floor
# 	Boston, MA  02110-1301, USA.

from spdsimple.phonetizer import Latinizer

class Swedisher(Latinizer):
	"""
	Specific-language (Swedish) example.
	In this case single method is overriden
	"""
	def __init__(self,charset='iso-8859-1'):
		Latinizer.__init__(self,
			charset=charset,
			speakable='',
			charnames={
				' ':'blanksteg',
				'.':'punkt',
				'*':'stjärna',
				'+':'plustecken',
				'=':'lika med',
				'#':'nummer',
				'€':'euro',
				'£':'pound',
				'&':'och-tecken',
				'@':'snabel a',
				'~':'tilde',
				'°':'grader',
				'_':'understruken',
				'"':'citattecken',
				'\'':'apostrof',
				'/':'snedstreck',
				'\\':'bakstreck',
				'$':'dollartecken',
				'(':'vänsterparentes',
				')':'högerparentes',
				'[':'vänster hakparentes',
				']':'höger hakparentes',
				'{':'vänster klammerparentes',
				'}':'höger klammerparentes',
				':':'kolon',
				';':'semikolon',
				',':'komma',
				'!':'uttropstecken',
				'?':'frågetecken',
				'-':'streck',
				'<':'mindre än',
				'>':'större än',
				'%':'procenttecken',
				'^':'utelämningstecken',
				'|':'vertikal linje'},
			keynames={
				'underscore':'understruken',
				'space':'blanksteg',
				' ':'blanksteg',
				'double-quote':'citattecken'},
			transmap={
				'š':'skj',
				'Š':'Skj',
				'č':'tj',
				'Č':'Tj',
				'ś':'skj',
				'Ś':'skj',
				'ć':'tj',
				'Ć':'tj',
				'ñ':'nj',
				'Ñ':'Nj',
				'æ':'ä',
				'Æ':'ä',
				'ç':'s',
				'Ç':'s',
				'œ':'ö',
				'Œ':'Ö',
				'ø':'ö',
				'Ø':'Ö',
				'ü':'y',
				'Ü':'Y'
				},
			untrans="äÄöÖåÅ",
			punctuation=",.?!\";:-",
			capformat="versal %s",
			charformat="tecken %d",
			accents={'diaeresis':u'trema',
				 'acute':u'akut',
				 'circumflex':u'cirkumflex',
				 'grave':u'grav'}
		)
	_spelling={
	    u'ł':'genomstruket l',
	    u'Ł':'genomstruket l',
	    u'ø':'genomstruket o',
	    u'Ø':'genomstruket o'}
	    
	def char_repr(self,c,nocap=False):
		s=self._spelling.get(c,None)
		if not s:
			return Latinizer.char_repr(self,c,nocap)
		if not nocap and c.isupper():
			return self.cap(s)
		return self.uni2cs(s,self.charset)
	    

